fsds.jmi package
================

.. automodule:: fsds.jmi
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

fsds.jmi.jmi module
-------------------

.. automodule:: fsds.jmi.jmi
   :members:
   :undoc-members:
   :show-inheritance:

fsds.jmi.jmi\_WIP module
------------------------

.. automodule:: fsds.jmi.jmi_WIP
   :members:
   :undoc-members:
   :show-inheritance:
